==> opendistillery-2.0.1.tar.gz: opendistillery-2.0.1/src/monitoring/advanced_dashboard.py <==
"""
Advanced Real-time Monitoring Dashboard
Enterprise-grade system monitoring with predictive analytics
"""

import streamlit as st
import plotly.graph_objects as go
import plotly.express as px
from plotly.subplots import make_subplots
import pandas as pd
import numpy as np
from datetime import datetime, timedelta
import asyncio
import aiohttp
import json

st.set_page_config(
    page_title="OpenDistillery Monitoring",
    page_icon="",
    layout="wide",
    initial_sidebar_state="expanded"
)

class AdvancedMonitoringDashboard:
    """Enterprise monitoring dashboard with real-time analytics"""
    
    def __init__(self):
        self.api_base_url = "http://localhost:8000/v2"
        self.refresh_interval = 5  # seconds
        
    def render_dashboard(self):
        """Render the complete monitoring dashboard"""
        
        # Dashboard header
        st.title(" OpenDistillery Advanced Monitoring Dashboard")
        st.markdown("Real-time system monitoring with predictive analytics")
        
        # Sidebar controls
        self.render_sidebar()
        
        # Main dashboard content
        col1, col2, col3, col4 = st.columns(4)
        
        with col1:
            self.render_kpi_card("Total Requests", "1,247", "", "15.3%")
        
        with col2:
            self.render_kpi_card("Success Rate", "98.7%", "✅", "2.1%")
        
        with col3:
            self.render_kpi_card("Avg Latency", "156ms", "", "-8.4%")
        
        with col4:
            self.render_kpi_card("Cost Savings", "$1,250", "💰", "12.7%")
        
        # Main content areas
        tab1, tab2, tab3, tab4, tab5 = st.tabs([
            " Real-time Metrics", 
            "🧠 Technique Performance", 
            " Quality Analytics", 
            "⚠ System Health",
            "🤖 AI Insights"
        ])
        
        with tab1:
            self.render_realtime_metrics()
        
        with tab2:
            self.render_technique_performance()
        
        with tab3:
            self.render_quality_analytics()
        
        with tab4:
            self.render_system_health()
        
        with tab5:
            self.render_ai_insights()
    
    def render_sidebar(self):
        """Render sidebar controls"""
        
        st.sidebar.title(" Dashboard Controls")
        
        # Time range selector
        time_range = st.sidebar.selectbox(
            "📅 Time Range",
            ["Last Hour", "Last 6 Hours", "Last 24 Hours", "Last 7 Days", "Last 30 Days"]
        )
        
        # Auto-refresh toggle
        auto_refresh = st.sidebar.checkbox("🔄 Auto Refresh", value=True)
        
        if auto_refresh:
            refresh_interval = st.sidebar.slider("Refresh Interval (seconds)", 1, 60, 5)
        
        # Filter options
        st.sidebar.subheader(" Filters")
        
        selected_techniques = st.sidebar.multiselect(
            "Techniques",
            ["quantum_superposition", "neural_architecture_search", "metacognitive", 
             "tree_of_thoughts", "multimodal_cot", "neuro_symbolic"],
            default=["metacognitive", "tree_of_thoughts"]
        )
        
        selected_models = st.sidebar.multiselect(
            "Models",
            ["gpt-4-turbo", "claude-3-5-sonnet", "gemini-1.5-pro", "command-r-plus"],
            default=["gpt-4-turbo", "claude-3-5-sonnet"]
        )
        
        # Alert settings
        st.sidebar.subheader("🚨 Alert Thresholds")
        latency_threshold = st.sidebar.slider("Max Latency (ms)", 100, 1000, 300)
        error_rate_threshold = st.sidebar.slider("Max Error Rate (%)", 0.1, 10.0, 2.0)
        
        # Export options
        st.sidebar.subheader("📤 Export")
        if st.sidebar.button("Export Dashboard Data"):
            self.export_dashboard_data()
    
    def render_kpi_card(self, title, value, icon, change):
        """Render KPI card"""
        
        change_color = "green" if change.startswith("+") or not change.startswith("-") else "red"
        change_icon = "" if change.startswith("+") else "📉" if change.startswith("-") else "➡"
        
        st.markdown(f"""
        <div style="
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            padding: 20px;
            border-radius: 10px;
            color: white;
            text-align: center;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        ">
            <h3 style="margin: 0; font-size: 2.5em;">{icon}</h3>
            <h2 style="margin: 10px 0; font-size: 1.8em;">{value}</h2>
            <p style="margin: 0; font-size: 1em; opacity: 0.8;">{title}</p>
            <p style="margin: 5px 0 0 0; color: {change_color};">
                {change_icon} {change} vs last period
            </p>
        </div>
        """, unsafe_allow_html=True)
    
    def render_realtime_metrics(self):
        """Render real-time metrics"""
        
        # Placeholder for real-time metrics rendering
        st.write("Real-time Metrics Placeholder")
    
    def render_technique_performance(self):
        """Render technique performance"""
        
        # Placeholder for technique performance rendering
        st.write("Technique Performance Placeholder")
    
    def render_quality_analytics(self):
        """Render quality analytics"""
        
        # Placeholder for quality analytics rendering
        st.write("Quality Analytics Placeholder")
    
    def render_system_health(self):
        """Render system health"""
        
        # Placeholder for system health rendering
        st.write("System Health Placeholder")
    
    def render_ai_insights(self):
        """Render AI insights"""
        
        # Placeholder for AI insights rendering
        st.write("AI Insights Placeholder")
    
    def export_dashboard_data(self):
        """Export dashboard data"""
        
        # Placeholder for data export functionality
        st.write("Export Dashboard Data Placeholder")

==> opendistillery-2.0.3.tar.gz: opendistillery-2.0.3/src/monitoring/advanced_dashboard.py <==
"""
Advanced Real-time Monitoring Dashboard
Enterprise-grade system monitoring with predictive analytics
"""

import streamlit as st
import plotly.graph_objects as go
import plotly.express as px
from plotly.subplots import make_subplots
import pandas as pd
import numpy as np
from datetime import datetime, timedelta
import asyncio
import aiohttp
import json

st.set_page_config(
    page_title="OpenDistillery Monitoring",
    page_icon="",
    layout="wide",
    initial_sidebar_state="expanded"
)

class AdvancedMonitoringDashboard:
    """Enterprise monitoring dashboard with real-time analytics"""
    
    def __init__(self):
        self.api_base_url = "http://localhost:8000/v2"
        self.refresh_interval = 5  # seconds
        
    def render_dashboard(self):
        """Render the complete monitoring dashboard"""
        
        # Dashboard header
        st.title(" OpenDistillery Advanced Monitoring Dashboard")
        st.markdown("Real-time system monitoring with predictive analytics")
        
        # Sidebar controls
        self.render_sidebar()
        
        # Main dashboard content
        col1, col2, col3, col4 = st.columns(4)
        
        with col1:
            self.render_kpi_card("Total Requests", "1,247", "", "15.3%")
        
        with col2:
            self.render_kpi_card("Success Rate", "98.7%", "CHECK", "2.1%")
        
        with col3:
            self.render_kpi_card("Avg Latency", "156ms", "", "-8.4%")
        
        with col4:
            self.render_kpi_card("Cost Savings", "$1,250", "💰", "12.7%")
        
        # Main content areas
        tab1, tab2, tab3, tab4, tab5 = st.tabs([
            " Real-time Metrics", 
            "Technique Performance", 
            " Quality Analytics", 
            "⚠ System Health",
            "AI Insights"
        ])
        
        with tab1:
            self.render_realtime_metrics()
        
        with tab2:
            self.render_technique_performance()
        
        with tab3:
            self.render_quality_analytics()
        
        with tab4:
            self.render_system_health()
        
        with tab5:
            self.render_ai_insights()
    
    def render_sidebar(self):
        """Render sidebar controls"""
        
        st.sidebar.title(" Dashboard Controls")
        
        # Time range selector
        time_range = st.sidebar.selectbox(
            "📅 Time Range",
            ["Last Hour", "Last 6 Hours", "Last 24 Hours", "Last 7 Days", "Last 30 Days"]
        )
        
        # Auto-refresh toggle
        auto_refresh = st.sidebar.checkbox("🔄 Auto Refresh", value=True)
        
        if auto_refresh:
            refresh_interval = st.sidebar.slider("Refresh Interval (seconds)", 1, 60, 5)
        
        # Filter options
        st.sidebar.subheader(" Filters")
        
        selected_techniques = st.sidebar.multiselect(
            "Techniques",
            ["quantum_superposition", "neural_architecture_search", "metacognitive", 
             "tree_of_thoughts", "multimodal_cot", "neuro_symbolic"],
            default=["metacognitive", "tree_of_thoughts"]
        )
        
        selected_models = st.sidebar.multiselect(
            "Models",
            ["gpt-4-turbo", "claude-3-5-sonnet", "gemini-1.5-pro", "command-r-plus"],
            default=["gpt-4-turbo", "claude-3-5-sonnet"]
        )
        
        # Alert settings
        st.sidebar.subheader("🚨 Alert Thresholds")
        latency_threshold = st.sidebar.slider("Max Latency (ms)", 100, 1000, 300)
        error_rate_threshold = st.sidebar.slider("Max Error Rate (%)", 0.1, 10.0, 2.0)
        
        # Export options
        st.sidebar.subheader("📤 Export")
        if st.sidebar.button("Export Dashboard Data"):
            self.export_dashboard_data()
    
    def render_kpi_card(self, title, value, icon, change):
        """Render KPI card"""
        
        change_color = "green" if change.startswith("+") or not change.startswith("-") else "red"
        change_icon = "" if change.startswith("+") else "📉" if change.startswith("-") else "➡"
        
        st.markdown(f"""
        <div style="
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            padding: 20px;
            border-radius: 10px;
            color: white;
            text-align: center;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        ">
            <h3 style="margin: 0; font-size: 2.5em;">{icon}</h3>
            <h2 style="margin: 10px 0; font-size: 1.8em;">{value}</h2>
            <p style="margin: 0; font-size: 1em; opacity: 0.8;">{title}</p>
            <p style="margin: 5px 0 0 0; color: {change_color};">
                {change_icon} {change} vs last period
            </p>
        </div>
        """, unsafe_allow_html=True)
    
    def render_realtime_metrics(self):
        """Render real-time metrics"""
        
        # Placeholder for real-time metrics rendering
        st.write("Real-time Metrics Placeholder")
    
    def render_technique_performance(self):
        """Render technique performance"""
        
        # Placeholder for technique performance rendering
        st.write("Technique Performance Placeholder")
    
    def render_quality_analytics(self):
        """Render quality analytics"""
        
        # Placeholder for quality analytics rendering
        st.write("Quality Analytics Placeholder")
    
    def render_system_health(self):
        """Render system health"""
        
        # Placeholder for system health rendering
        st.write("System Health Placeholder")
    
    def render_ai_insights(self):
        """Render AI insights"""
        
        # Placeholder for AI insights rendering
        st.write("AI Insights Placeholder")
    
    def export_dashboard_data(self):
        """Export dashboard data"""
        
        # Placeholder for data export functionality
        st.write("Export Dashboard Data Placeholder")
